@@ -151,6 +151,9 @@ class AIOModel(Model, metaclass=AIOModelBase):
         def __getattr__(self, name: str) -> Any:
             ...
 
+        def __setattr__(self, name: str, value: Any) -> None:
+            ...
+
     # Class methods
     # -------------
 
@@ -294,11 +297,14 @@ class AIOModel(Model, metaclass=AIOModelBase):
 class AIOQuery(Query, Generic[TVAIOModel]):
     model: Type[TVAIOModel]
 
+    if TYPE_CHECKING:
+        _order_by: Optional[tuple]
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.manager = self.model._manager
 
-    def __await__(self) -> Generator[Any, None, List[TVAIOModel]]:
+    def __await__(self) -> Generator[Any, None, Any]:
         return self.manager.run(self).__await__()
 
 
@@ -329,7 +335,7 @@ class BaseModelSelect(AIOQuery[TVAIOModel]):
 
 class AIOModelSelect(BaseModelSelect[TVAIOModel], ModelSelect):
     def __aiter__(self) -> AsyncGenerator[TVAIOModel, None]:
-        return self.manager.run(self).__aiter__()
+        return self.manager.run(self).__aiter__()  # type: ignore[return-value]
 
     @overload
     def __getitem__(self, value: int) -> Coroutine[Any, Any, TVAIOModel]:
@@ -421,6 +427,9 @@ class AIOModelSelect(BaseModelSelect[TVAIOModel], ModelSelect):
         for_update: Callable[..., AIOModelSelect[TVAIOModel]]
         lateral: Callable[..., AIOModelSelect[TVAIOModel]]
 
+        def __await__(self) -> Generator[Any, None, List[TVAIOModel]]:
+            return self.manager.run(self).__await__()
+
 
 class AIOModelCompoundSelectQuery(
     BaseModelSelect[TVAIOModel],
